==> foundation-table-2.1.1.tgz: package/README.md <==
# @billogram/foundation-table

> React table components

## Install

```
yarn add @billogram/foundation-table
```

## Usage

```tsx
import {
    FoundationTable,
    FoundationTableDataConsumer,
    FoundationTableDataProvider,
    FoundationTableFetchMoreButtons,
    FoundationTableSpinner,
    FoundationTableState,
    // Expand
    FoundationTableRowExpandResult,
    FoundationTableRowExpandResultGroup,
    FoundationTableRowExpandResultProperty,
    FoundationTableRowExpandResultPropertyGroup,
    FoundationTableRowExpandResultPropertyGroupSection,
    // Row
    FoundationTableCell,
    FoundationTableCellAsyncButton,
    FoundationTableCellExpandButton,
    FoundationTableCellLinkButton,
    FoundationTableCellMainValue,
    FoundationTableCellMenu,
    FoundationTableCellRouteButton,
    FoundationTableCellSingleControlGroup,
    FoundationTableCellValue,
    FoundationTableRow,
    FoundationTableRowGroupContext,
    useTableRowGroupContext,
    // Search result group
    FoundationTableRowSearchResult,
    FoundationTableRowSearchResultGroup,
    searchField,
    // Search result overview
    FoundationSearchResultOverview,
} from '@billogram/foundation-table';
```

See [types](src/types.ts) for exported types.

## API

See [docs](docs/README.md).

## Note

This library is being published with our use cases in mind and is not necessarily meant to be consumed by the broader public. We probably won't take your feature requests unless they align with our own needs.

## License

MIT

==> foundation-table-3.1.2.tgz: package/README.md <==
# @billogram/foundation-table

> React table components

## Install

```
yarn add @billogram/foundation-table
```

## Usage

```tsx
import {
    createTable,
    createTableProvider,
    FoundationTableFetchMoreButtons,
    FoundationTableSpinner,
    FoundationTableState,
    // Expand
    FoundationTableRowExpandResult,
    FoundationTableRowExpandResultGroup,
    FoundationTableRowExpandResultGroupSection,
    FoundationTableRowExpandResultItem,
    FoundationTableRowExpandResultProperty,
    FoundationTableRowExpandResultPropertyGroup,
    FoundationTableRowExpandResultPropertyGroupSection,
    // Row
    createTableRowProvider,
    FoundationTableCell,
    FoundationTableCellAsyncButton,
    FoundationTableCellDualValue,
    FoundationTableCellExpandButton,
    FoundationTableCellIcon,
    FoundationTableCellLinkButton,
    FoundationTableCellMainValue,
    FoundationTableCellMenu,
    FoundationTableCellRouteButton,
    FoundationTableCellSingleControlGroup,
    FoundationTableCellValue,
    FoundationTableRow,
    // Search result group
    FoundationTableRowSearchResult,
    FoundationTableRowSearchResultGroup,
    searchField,
    // Search result overview
    FoundationSearchResultOverview,
} from '@billogram/foundation-table';
```

See [types](src/types.ts) for exported types.

## API

See [docs](docs/README.md).

## Note

This library is being published with our use cases in mind and is not necessarily meant to be consumed by the broader public. We probably won't take your feature requests unless they align with our own needs.

## License

MIT
